#
# Cookbook Name:: systemd_networkd_team
# Recipe:: default
#
# Copyright 2014, Intel Corp
#
# All rights reserved - Do Not Redistribute
#

outdir = node[ "SystemdNetworkd" ][ "outdir" ]

### Create network/team directory if necessary ###
directory "#{outdir}/team" do
  owner 'systemd-network'
  group 'systemd-network'
  mode '0755'
  action :create
end

if node.include?( "SystemdNetworkd" )    
  if node[ "SystemdNetworkd" ].include?( "Teams" )    
    node[ "SystemdNetworkd" ][ "Teams" ].each do |team_name,team_settings|

      template "#{outdir}/team/team_#{team_name}.netdev" do
        source "team/team_netdev.erb"
        variables({
          :TeamName => team_name
        })
        mode 0644
        owner "systemd-network"
        group "systemd-network"
        action :create
      end

      if node[ "SystemdNetworkd" ][ "Teams" ][ "#{team_name}" ].include?( "Attributes" ) ||
        node[ "SystemdNetworkd" ][ "Teams" ][ "#{team_name}" ].include?( "Vlans" ) 
        template "#{outdir}/team/team_#{team_name}.swport" do
          source "team/team_swport.erb"
          variables(:DevName => team_name)
          mode 0644
          owner "systemd-network"
          group "systemd-network"
          action :create
        end
      end

      if node[ "SystemdNetworkd" ][ "Teams" ][ "#{team_name}" ].include?( "FDB" )
        template "#{outdir}/team/team_#{team_name}.network" do
          source "team/team_network.erb"
          variables(:DevName => team_name)
          mode 0644
          owner "systemd-network"
          group "systemd-network"
          action :create
          notifies :restart, "service[systemd-networkd]", :delayed
        end
      end

      if node[ "SystemdNetworkd" ][ "Teams" ][ "#{team_name}" ].include?( "Members" )
        node[ "SystemdNetworkd" ][ "Teams" ][ "#{team_name}" ][ "Members" ].each do |member|
        
          template "#{outdir}/team/team_#{team_name}_#{member}.network" do
            source "team/team_network_member.erb"
            variables({
                :TeamName => team_name,
                :Member => member
            })
            mode 0644
            owner "systemd-network"
            group "systemd-network"
            action :create
            notifies :restart, "service[systemd-networkd]", :delayed
          end
           
          if node[ "SystemdNetworkd" ][ "Teams" ][ "#{team_name}" ].include?( "Enabled" )
            if node[ "SystemdNetworkd" ][ "Teams" ][ "#{team_name}" ][ "Enabled" ] == true || node[ "SystemdNetworkd" ][ "Backup" ] == true 

              link "#{outdir}/team_#{team_name}_#{member}.network" do
                to "#{outdir}/team/team_#{team_name}_#{member}.network"
              end

            end
          end

        end
      end

      if node[ "SystemdNetworkd" ][ "Teams" ][ "#{team_name}" ].include?( "Enabled" )
        if node[ "SystemdNetworkd" ][ "Teams" ][ "#{team_name}" ][ "Enabled" ] == true || node[ "SystemdNetworkd" ][ "Backup" ] == true
        
          link "#{outdir}/team_#{team_name}.netdev" do
            to "#{outdir}/team/team_#{team_name}.netdev"
          end

          if node[ "SystemdNetworkd" ][ "Teams" ][ "#{team_name}" ].include?( "Attributes" ) || node[ "SystemdNetworkd" ][ "Teams" ][ "#{team_name}" ].include?( "Vlans" )
            link "#{outdir}/team_#{team_name}.swport" do
              to "#{outdir}/team/team_#{team_name}.swport"
            end
          end

          if node[ "SystemdNetworkd" ][ "Teams" ][ "#{team_name}" ].include?( "FDB" )
            link "#{outdir}/team_#{team_name}.network" do
              to "#{outdir}/team/team_#{team_name}.network"
            end
          end

        end
      end

    end
  end
end


